@@ -314,7 +314,6 @@ by user main app class.
 """
 from abc import ABC, abstractmethod
 import re
-import traceback
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type
 
@@ -327,7 +326,7 @@ from ae.core import DEBUG_LEVELS                                    # type: igno
 from ae.console import ConsoleApp                                   # type: ignore
 
 
-__version__ = '0.1.45'
+__version__ = '0.1.46'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -876,28 +875,16 @@ class MainAppBase(ConsoleApp, ABC):
 
     @staticmethod
     def on_flow_popup_close(_flow_key: str, _popup_args: Dict[str, Any]) -> bool:
-        """ default popup close handler of FlowPopup widget, ensuring update of :attr:`flow_path`. """
+        """ default popup close handler of FlowPopup widget, ensuring update of :attr:`flow_path`.
+
+        :param _flow_key:       unused flow key.
+        :param _popup_args:     unused popup args.
+        :return:                always returning True.
+        """
         return True
 
     # other helper methods and default event handlers
 
-    def call_method(self, method: str, *args, **kwargs) -> Any:
-        """ call method of this instance with the passed args, catching and logging exceptions preventing app exit.
-
-        :param method:      name of the main app method to call.
-        :param args:        args passed to the main app method to be called.
-        :param kwargs:      kwargs passed to the main app method to be called.
-        :return:            return value of the called method or None if method throws exception or does not exist.
-        """
-        event_callback = getattr(self, method, None)
-        if event_callback:
-            assert callable(event_callback), f"MainAppBase.call_method: {method!r} is not callable ({args}, {kwargs})"
-            try:
-                return event_callback(*args, **kwargs)
-            except (AttributeError, IndexError, LookupError, ValueError, Exception) as ex:
-                self.po(f" ***  MainAppBase.call_method({method}, {args}, {kwargs}): {ex}\n{traceback.format_exc()}")
-        return None
-
     def find_image(self, image_name: str, height: float = 32.0, light_theme: bool = True) -> Optional[RegisteredFile]:
         """ find best fitting image in img app folder (see also :meth:`~MainAppBase.img_file` for easier usage).
 
@@ -906,12 +893,20 @@ class MainAppBase(ConsoleApp, ABC):
         :param light_theme:     preferred theme (dark/light) of the image.
         :return:                image file object (RegisteredFile/CachedFile) if found else None.
         """
-        def property_matcher(file):
-            """ find images with matching theme. """
+        def property_matcher(file) -> bool:
+            """ find images with matching theme.
+
+            :param file:        RegisteredFile instance.
+            :return:            True if theme is matching.
+            """
             return bool(file.properties.get('light', 0)) == light_theme
 
-        def file_sorter(file):
-            """ sort images files by height delta. """
+        def file_sorter(file) -> float:
+            """ sort images files by height delta.
+
+            :param file:        RegisteredFile instance.
+            :return:            height delta.
+            """
             return abs(file.properties.get('height', -MAX_FONT_SIZE) - height)
 
         if self.image_files:
@@ -929,7 +924,13 @@ class MainAppBase(ConsoleApp, ABC):
         return None
 
     def img_file(self, image_name: str, font_size: Optional[float] = None, light_theme: Optional[bool] = None) -> str:
-        """ shortcutting :meth:`~MainAppBase.find_image` method w/o bound property for to get image file path. """
+        """ shortcutting :meth:`~MainAppBase.find_image` method w/o bound property for to get image file path.
+
+        :param image_name:      image name (file name stem).
+        :param font_size:       optional font size in pixels.
+        :param light_theme:     optional theme (True=light, False=dark).
+        :return:                file path of image file or empty string if image file not found.
+        """
         if font_size is None:
             font_size = self.font_size
         if light_theme is None:
@@ -941,15 +942,21 @@ class MainAppBase(ConsoleApp, ABC):
         return ''
 
     def key_press_from_framework(self, modifiers: str, key: str) -> bool:
-        """ dispatch key press event, coming normalized from the UI framework. """
+        """ dispatch key press event, coming normalized from the UI framework.
+
+        :param modifiers:       modifier keys.
+        :param key:             key character.
+        :return:                True if key got consumed/used else False.
+        """
         self.vpo(f"MainAppBase.key_press_from_framework({modifiers}+{key})")
         event_name = f'on_key_press_of_{modifiers}_{key}'
         en_lower = event_name.lower()
-        if not self.call_method(event_name):
-            if event_name == en_lower or not self.call_method(en_lower):
-                # always pass lower key code (enaml/Qt is passing upper-case key code if Shift modifier is pressed)
-                return self.call_method('on_key_press', modifiers, key.lower())
-        return True
+        if self.call_method(en_lower):
+            return True
+        if event_name != en_lower and self.call_method(event_name):
+            return True
+        # call default handler; pass lower key code (enaml/Qt sends upper-case key code if Shift modifier is pressed)
+        return self.call_method('on_key_press', modifiers, key.lower()) or False
 
     def load_images(self):
         """ load images from app folder img. """
